)]}'
{
  "commit": "a18ff1bde0c3da9ece3ba60e6eae2ef87f91a12e",
  "tree": "4a822b5150773dd979f723232ed2d7169214d9bd",
  "parents": [
    "57ac895a7f22d235f637317f58a2d9ba6ec91a27"
  ],
  "author": {
    "name": "Jeff Dike",
    "email": "jdike@addtoit.com",
    "time": "Sun May 06 14:51:19 2007 -0700"
  },
  "committer": {
    "name": "Linus Torvalds",
    "email": "torvalds@woody.linux-foundation.org",
    "time": "Mon May 07 12:13:02 2007 -0700"
  },
  "message": "uml: speed up exec\n\nflush_thread doesn\u0027t need to do a full page table walk in order to clear the\naddress space.  It knows what the end result needs to be, so it can call unmap\ndirectly.\n\nThis results in a 10-20% speedup in an exec from bash.\n\nSigned-off-by: Jeff Dike \u003cjdike@linux.intel.com\u003e\nCc: Paolo \u0027Blaisorblade\u0027 Giarrusso \u003cblaisorblade@yahoo.it\u003e\nSigned-off-by: Andrew Morton \u003cakpm@linux-foundation.org\u003e\nSigned-off-by: Linus Torvalds \u003ctorvalds@linux-foundation.org\u003e\n",
  "tree_diff": [
    {
      "type": "modify",
      "old_id": "54b795951372a8034cf40d30be457897d01b1c25",
      "old_mode": 33188,
      "old_path": "arch/um/kernel/skas/exec.c",
      "new_id": "580eb6468949f56646732119d07745013dc36d95",
      "new_mode": 33188,
      "new_path": "arch/um/kernel/skas/exec.c"
    }
  ]
}
